@@ -1,11 +1,11 @@
 "summary.binomRDtest"<-function(object,...)
 {
 
-args<-list(...)
-if(is.null(args$digits))
+aargs<-list(...)
+if(is.null(aargs$digits))
  {digits<-4}
 else
- {digits<-args$digits}
+ {digits<-aargs$digits}
 
 
 cat("Summary statistics: \n")
